@@ -1,4 +1,4 @@
-# $Id: Chronos.pm,v 1.36 2002/08/04 20:40:40 nomis80 Exp $
+# $Id: Chronos.pm,v 1.45 2002/08/12 18:31:55 nomis80 Exp $
 #
 # Copyright (C) 2002  Linux Qubec Technologies 
 #
@@ -37,8 +37,10 @@ use Chronos::Action::UserPrefs;
 use Chronos::Action::SaveUserPrefs;
 use Chronos::Action::GetFile;
 use Chronos::Action::DelFile;
+use HTML::Entities;
+use POSIX qw(strftime);
 
-our $VERSION = "1.1.3";
+our $VERSION = "1.1.4";
 sub VERSION { $VERSION }
 
 sub handler {
@@ -71,7 +73,8 @@ sub handler {
         my $action = $chronos->{r}->param('action');
         my $object = $chronos->{r}->param('object');
         $r->note_basic_auth_failure;
-        $r->log_reason("user $user: not authorized (action: $action, object: $object)");
+        $r->log_reason(
+            "user $user: not authorized (action: $action, object: $object)");
         return AUTH_REQUIRED;
     }
 }
@@ -88,11 +91,12 @@ sub go {
 
     my $lang = $self->lang;
     Language( Decode_Language($lang) );
+    $ENV{LC_TIME} = $lang;
 
     if ( $self->action->redirect ) {
         $self->action->content;
         return REDIRECT;
-    } elsif ($self->action->freeform) {
+    } elsif ( $self->action->freeform ) {
         return $self->action->execute;
     } else {
         $self->header;
@@ -107,7 +111,9 @@ sub lang {
     my $self        = shift;
     my $dbh         = $self->dbh;
     my $user_quoted = $dbh->quote( $self->user );
-    my $lang        = $dbh->selectrow_array("SELECT lang FROM user WHERE user = $user_quoted") || 'fr';
+    my $lang        =
+      $dbh->selectrow_array("SELECT lang FROM user WHERE user = $user_quoted")
+      || 'fr';
     return $lang;
 }
 
@@ -115,9 +121,10 @@ sub header {
     my $self = shift;
 
     my $object = $self->action->object;
-    my $user = $self->user;
+    my $user   = $self->user;
     my $text   = $self->gettext;
-    my $dbh = $self->dbh;
+    my $dbh    = $self->dbh;
+    my $uri    = $self->{r}->uri;
 
     my ( $year, $month, $day ) = $self->day;
 
@@ -125,8 +132,13 @@ sub header {
     # leaves for the night, he'll come back in the morning with a showday
     # automagically showing tomorrow! (or today, whatever)
     my @today = Today();
-    if ($self->{r}->param('action') eq 'showday' and $today[0] == $year and $today[1] == $month and $today[2] == $day) {
-        $self->{r}->header_out('Refresh', "360;url=/Chronos?action=showday&object=$object");
+    if (    $self->{r}->param('action') eq 'showday'
+        and $today[0] == $year
+        and $today[1] == $month
+        and $today[2] == $day )
+    {
+        $self->{r}->header_out( 'Refresh',
+            "3600;url=$uri?action=showday&object=$object" );
     }
 
     $self->{page} .= <<EOF;
@@ -144,22 +156,34 @@ sub header {
     <tr><td>
         <table width="100%" cellspacing=0>
             <tr>
-                <td class=top>Chronos $VERSION - <a class=header href="/Chronos?action=userprefs">$user</a></td>
+                <td class=top>Chronos $VERSION - <a class=header href="$uri?action=userprefs">$user</a></td>
                 <td class=top align=right><select name="object" style="background-color:black; color:white" onChange="switchobject(this.value)">
 EOF
-    
-    my $user_quoted = $dbh->quote($self->user);
-    my $from_user = $dbh->selectall_arrayref("SELECT user, name, email FROM user WHERE user = $user_quoted OR public_readable = 'Y' OR public_writable = 'Y' ORDER BY name, user");
-    my $from_acl = $dbh->selectall_arrayref("SELECT user.user, user.name, user.email FROM user, acl WHERE acl.object = user.user AND acl.user = $user_quoted AND (acl.can_read = 'Y' OR acl.can_write = 'Y')");
+
+    my $user_quoted = $dbh->quote( $self->user );
+    my $from_user   =
+      $dbh->selectall_arrayref(
+"SELECT user, name, email FROM user WHERE user = $user_quoted OR public_readable = 'Y' OR public_writable = 'Y' ORDER BY name, user"
+      );
+    my $from_acl =
+      $dbh->selectall_arrayref(
+"SELECT user.user, user.name, user.email FROM user, acl WHERE acl.object = user.user AND acl.user = $user_quoted AND (acl.can_read = 'Y' OR acl.can_write = 'Y')"
+      );
     my %users = map { $_->[0] => [ $_->[1], $_->[2] ] } @$from_user, @$from_acl;
-    foreach (sort { $users{$a}[0] cmp $users{$b}[0] || $a cmp $b } keys %users) {
-        my $string = ($users{$_}[0] || $_) . ($users{$_}[1] ? " &lt;" . $users{$_}[1] . "&gt;" : '');
+    foreach (
+        sort { $users{$a}[0] cmp $users{$b}[0] || $a cmp $b }
+        keys %users
+      )
+    {
+        my $string =
+          ( $users{$_}[0] || $_ )
+          . ( $users{$_}[1] ? " &lt;" . $users{$_}[1] . "&gt;" : '' );
         my $selected = $self->action->object eq $_ ? 'selected' : '';
         $self->{page} .= <<EOF;
         <option value="$_" $selected>$string</option>
 EOF
     }
-    
+
     $self->{page} .= <<EOF;
                 </select></td>
             </tr>
@@ -205,11 +229,12 @@ sub stylesheet {
 
 sub javascript {
     my $self = shift;
-    my ($year, $month, $day) = $self->day;
+    my ( $year, $month, $day ) = $self->day;
+    my $uri    = $self->{r}->uri;
     my $action = $self->{r}->param('action');
     return <<EOF
 function switchobject(object) {
-    window.location = ("/Chronos?object=" + object + "@{[$action ? "&action=$action" : '']}&year=$year&month=$month&day=$day");
+    window.location = ("$uri?object=" + object + "@{[$action ? "&action=$action" : '']}&year=$year&month=$month&day=$day");
 }
 EOF
 }
@@ -224,7 +249,8 @@ sub sendpage {
 sub conf {
     my $self = shift;
     if ( not $self->{conf} ) {
-        $self->{conf} = Chronos::Static::conf();
+        my $file = $self->{r}->dir_config("ChronosConfig");
+        $self->{conf} = Chronos::Static::conf($file);
     }
     return $self->{conf};
 }
@@ -239,12 +265,18 @@ sub dbh {
     my $db_user = $conf->{DB_USER} || 'chronos';
     my $db_pass = $conf->{DB_PASS};
     if ( not $db_pass ) {
-        $self->{r}->log_error("I need a DB_PASS in /etc/chronos.conf");
+        $self->{r}
+          ->log_error("I need a DB_PASS directive in the configuration file");
         return;
     }
 
-    my $dsn = "dbi:$db_type:$db_name" . ( $db_host ? ":$db_host" : '' ) . ( $db_port ? ":$db_port" : '' );
-    my $dbh = DBI->connect( $dsn, $db_user, $db_pass, { RaiseError => 1, PrintError => 0 } );
+    my $dsn =
+      "dbi:$db_type:$db_name"
+      . ( $db_host ? ":$db_host" : '' )
+      . ( $db_port ? ":$db_port" : '' );
+    my $dbh =
+      DBI->connect( $dsn, $db_user, $db_pass,
+        { RaiseError => 1, PrintError => 0 } );
     return $dbh;
 }
 
@@ -260,35 +292,35 @@ sub action {
     my $self = shift;
 
     my $action;
-    if (my $name = $self->{r}->param('action')) {
+    if ( my $name = $self->{r}->param('action') ) {
         $action = $name;
-    } elsif (my $path_info = $self->{r}->path_info) {
+    } elsif ( my $path_info = $self->{r}->path_info ) {
         ($action) = $path_info =~ /^\/([^\/]+)/;
     } else {
         $action = 'showday';
     }
-        
+
     if ( $action eq 'showday' ) {
         return Chronos::Action::Showday->new($self);
     } elsif ( $action eq 'saveevent' ) {
         return Chronos::Action::SaveEvent->new($self);
     } elsif ( $action eq 'editevent' ) {
         return Chronos::Action::EditEvent->new($self);
-    } elsif ($action eq 'showmonth') {
+    } elsif ( $action eq 'showmonth' ) {
         return Chronos::Action::Showmonth->new($self);
-    } elsif ($action eq 'showweek') {
+    } elsif ( $action eq 'showweek' ) {
         return Chronos::Action::Showweek->new($self);
-    } elsif ($action eq 'edittask') {
+    } elsif ( $action eq 'edittask' ) {
         return Chronos::Action::EditTask->new($self);
-    } elsif ($action eq 'savetask') {
+    } elsif ( $action eq 'savetask' ) {
         return Chronos::Action::SaveTask->new($self);
-    } elsif ($action eq 'userprefs') {
+    } elsif ( $action eq 'userprefs' ) {
         return Chronos::Action::UserPrefs->new($self);
-    } elsif ($action eq 'saveuserprefs') {
+    } elsif ( $action eq 'saveuserprefs' ) {
         return Chronos::Action::SaveUserPrefs->new($self);
-    } elsif ($action eq 'getfile') {
+    } elsif ( $action eq 'getfile' ) {
         return Chronos::Action::GetFile->new($self);
-    } elsif ($action eq 'delfile') {
+    } elsif ( $action eq 'delfile' ) {
         return Chronos::Action::DelFile->new($self);
     } else {
         return Chronos::Action::Showday->new($self);
@@ -296,10 +328,10 @@ sub action {
 }
 
 sub day {
-    my $self = shift;
-    my $year = $self->{r}->param('year');
+    my $self  = shift;
+    my $year  = $self->{r}->param('year');
     my $month = $self->{r}->param('month');
-    my $day = $self->{r}->param('day');
+    my $day   = $self->{r}->param('day');
     my @today = Today();
     $year  ||= $today[0];
     $month ||= $today[1];
@@ -320,29 +352,36 @@ sub event {
     my $eid  = shift;
     $self->{events} ||= {};
     if ( not $self->{events}{$eid} ) {
-        $self->{events}{$eid} = $self->dbh->selectrow_hashref("SELECT * FROM events WHERE eventid = $eid");
+        $self->{events}{$eid} =
+          $self->dbh->selectrow_hashref(
+            "SELECT * FROM events WHERE eventid = $eid");
     }
     return $self->{events}{$eid};
 }
 
 sub minimonth {
-    my $self = shift;
+    my $self   = shift;
     my $object = $self->action->object;
+    my $uri    = $self->{r}->uri;
     my ( $year, $month, $day ) = @_;
-    my $nocur = ! $day;
+    my $nocur = !$day;
     $day ||= 1;
 
-    my ( $prev_year,      $prev_month,      $prev_day )      = Add_Delta_YM( $year, $month, $day, 0,  -1 );
-    my ( $next_year,      $next_month,      $next_day )      = Add_Delta_YM( $year, $month, $day, 0,  1 );
-    my ( $prev_prev_year, $prev_prev_month, $prev_prev_day ) = Add_Delta_YM( $year, $month, $day, -1, 0 );
-    my ( $next_next_year, $next_next_month, $next_next_day ) = Add_Delta_YM( $year, $month, $day, 1,  0 );
+    my ( $prev_year, $prev_month, $prev_day ) =
+      Add_Delta_YM( $year, $month, $day, 0, -1 );
+    my ( $next_year, $next_month, $next_day ) =
+      Add_Delta_YM( $year, $month, $day, 0, 1 );
+    my ( $prev_prev_year, $prev_prev_month, $prev_prev_day ) =
+      Add_Delta_YM( $year, $month, $day, -1, 0 );
+    my ( $next_next_year, $next_next_month, $next_next_day ) =
+      Add_Delta_YM( $year, $month, $day, 1, 0 );
 
     my $return = <<EOF;
 <!-- Begin Chronos::minimonth -->
 <table class=minimonth>
     <tr>
         <!-- This is all in one big line so that it doesn't get separated. -->
-        <th class=minimonth colspan=7><a class=minimonthheader href="/Chronos?action=showday&amp;object=$object&amp;year=$prev_prev_year&amp;month=$prev_prev_month&amp;day=$prev_prev_day">&lt;&lt;</a>&nbsp;<a class=minimonthheader href="/Chronos?action=showday&amp;object=$object&amp;year=$prev_year&amp;month=$prev_month&amp;day=$prev_day">&lt;</a>&nbsp;<a class=minimonthheader href="/Chronos?action=showmonth&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">@{[ucfirst Month_to_Text($month)]}</a>&nbsp;$year&nbsp;<a class=minimonthheader href="/Chronos?action=showday&amp;object=$object&amp;year=$next_year&amp;month=$next_month&amp;day=$next_day">&gt;</a>&nbsp;<a class=minimonthheader href="/Chronos?action=showday&amp;object=$object&amp;year=$next_next_year&amp;month=$next_next_month&amp;day=$next_next_day">&gt;&gt;</a></th>
+        <th class=minimonth colspan=7><a class=minimonthheader href="$uri?action=showday&amp;object=$object&amp;year=$prev_prev_year&amp;month=$prev_prev_month&amp;day=$prev_prev_day">&lt;&lt;</a>&nbsp;<a class=minimonthheader href="$uri?action=showday&amp;object=$object&amp;year=$prev_year&amp;month=$prev_month&amp;day=$prev_day">&lt;</a>&nbsp;<a class=minimonthheader href="$uri?action=showmonth&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">@{[ucfirst Month_to_Text($month)]}</a>&nbsp;$year&nbsp;<a class=minimonthheader href="$uri?action=showday&amp;object=$object&amp;year=$next_year&amp;month=$next_month&amp;day=$next_day">&gt;</a>&nbsp;<a class=minimonthheader href="$uri?action=showday&amp;object=$object&amp;year=$next_next_year&amp;month=$next_next_month&amp;day=$next_next_day">&gt;&gt;</a></th>
     </tr>
     <tr>
 EOF
@@ -367,10 +406,10 @@ EOF
     #     Consistent with this practice, current norms and standards (such
     #     as ISO/R 2015-1971, DIN 1355 and ISO 8601) define the Monday as
     #     the first day of the week.
-    
+
     foreach ( 1 .. 7 ) {
         $return .= <<EOF;
-        <td>@{[Day_of_Week_Abbreviation($_)]}</td>
+        <td>@{[encode_entities(Day_of_Week_Abbreviation($_))]}</td>
 EOF
     }
 
@@ -379,15 +418,16 @@ EOF
 EOF
 
     my $dow_first = Day_of_Week( $year, $month, 1 );
-    if ($dow_first != 1) {
+    if ( $dow_first != 1 ) {
         $return .= <<EOF;
     <tr>
 EOF
     }
     foreach ( 1 .. ( $dow_first - 1 ) ) {
-        my ( $mini_year, $mini_month, $mini_day ) = Add_Delta_Days( $year, $month, 1, -( $dow_first - $_ ) );
+        my ( $mini_year, $mini_month, $mini_day ) =
+          Add_Delta_Days( $year, $month, 1, -( $dow_first - $_ ) );
         $return .= <<EOF;
-        <td><a class=dayothermonth href="/Chronos?action=showday&amp;object=$object&amp;year=$mini_year&amp;month=$mini_month&amp;day=$mini_day">$mini_day</a></td>
+        <td><a class=dayothermonth href="$uri?action=showday&amp;object=$object&amp;year=$mini_year&amp;month=$mini_month&amp;day=$mini_day">$mini_day</a></td>
 EOF
     }
 
@@ -395,7 +435,10 @@ EOF
     my ( $curyear, $curmonth, $curday ) = Today();
     foreach ( 1 .. $days ) {
         my $tdclass = "class=curday" if $_ == $day and not $nocur;
-        my $class = ( $_ == $curday and $month == $curmonth ) ? 'today' : 'daycurmonth';
+        my $class =
+          ( $_ == $curday and $month == $curmonth and $year == $curyear )
+          ? 'today'
+          : 'daycurmonth';
 
         my $dow = Day_of_Week( $year, $month, $_ );
         if ( $dow == 1 ) {
@@ -404,7 +447,7 @@ EOF
 EOF
         }
         $return .= <<EOF;
-        <td $tdclass><a class=$class href="/Chronos?action=showday&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$_">$_</a></td>
+        <td $tdclass><a class=$class href="$uri?action=showday&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$_">$_</a></td>
 EOF
         if ( $dow == 7 ) {
             $return .= <<EOF;
@@ -415,19 +458,22 @@ EOF
 
     my $dow_last = Day_of_Week( $year, $month, $days );
     foreach ( ( $dow_last + 1 ) .. 7 ) {
-        my ( $mini_year, $mini_month, $mini_day ) = Add_Delta_Days( $year, $month, $days, ( $_ - $dow_last ) );
+        my ( $mini_year, $mini_month, $mini_day ) =
+          Add_Delta_Days( $year, $month, $days, ( $_ - $dow_last ) );
         $return .= <<EOF;
-        <td><a class=dayothermonth href="/Chronos?action=showday&amp;object=$object&amp;year=$mini_year&amp;month=$mini_month&amp;day=$mini_day">$mini_day</a></td>
+        <td><a class=dayothermonth href="$uri?action=showday&amp;object=$object&amp;year=$mini_year&amp;month=$mini_month&amp;day=$mini_day">$mini_day</a></td>
 EOF
     }
 
-    my $text = $self->gettext;
-    my $today = Date_to_Text_Long( $curyear, $curmonth, $curday );
+    my $text  = $self->gettext;
+    my $today =
+      $self->format_date( $self->conf->{MINIMONTH_DATE_FORMAT} || '%(long)',
+        $curyear, $curmonth, $curday, 0, 0, 0 );
     $return .= <<EOF;
     </tr>
     <tr>
         <td colspan=7 class=minimonthfooter>
-            <a class=daycurmonth href="/Chronos?action=showday&amp;object=$object&amp;year=$curyear&amp;month=$curmonth&amp;day=$curday">$text->{today}</a>, $today
+            <a class=daycurmonth href="$uri?action=showday&amp;object=$object&amp;year=$curyear&amp;month=$curmonth&amp;day=$curday">$text->{today}</a>, $today
         </td>
     </tr>
 </table>
@@ -442,22 +488,16 @@ EOF
 # This really should be transformed into a method of an object Chronos::Day. But
 # what use would be an object with only one method? Feel free to implement
 # Chronos::Day if you wish. 
-{
-    # Cache statements so that multiple calls to events_per_day will not build
-    # multiple statements. It is assumed (I haven't searched) that when a
-    # database handle dies, the statement handles that are its children also are
-    # destroyed and therefore the "if (not $sth_events)" check should work.
-    my $sth_events;
-    my $sth_participants;
-    
-    sub events_per_day {
-        my $self = shift;
-        my $dbh = $self->dbh;
-        my $object = $self->action->object;
-        my ($year, $month, $day) = @_;
+sub events_per_day {
+    my $self   = shift;
+    my $view   = uc shift;                # 'month' or 'week'
+    my $uri    = $self->{r}->uri;
+    my $dbh    = $self->dbh;
+    my $object = $self->action->object;
+    my ( $year, $month, $day ) = @_;
+    my $conf = $self->conf;
 
-        if (not $sth_events) {
-            $sth_events = $dbh->prepare( <<EOF );
+    my $sth_events = $dbh->prepare( <<EOF );
 SELECT eid, name, start_date, start_time, end_date, end_time
 FROM events
 WHERE
@@ -466,7 +506,7 @@ WHERE
     AND end_date >= ?
 ORDER BY start_date, start_time, name
 EOF
-            $sth_participants = $dbh->prepare( <<EOF );
+    my $sth_participants = $dbh->prepare( <<EOF );
 SELECT events.eid, events.name, events.start_date, events.start_time, events.end_date, events.end_time
 FROM events, participants
 WHERE
@@ -476,46 +516,93 @@ WHERE
     AND events.end_date >= ?
 ORDER BY events.start_date, events.start_time, events.name
 EOF
-        }
 
-        # The two statements above take as input:
-        # 1) The current object
-        # 2) Today's date
-        # 3) Today's date
+    # The two statements above take as input:
+    # 1) The current object
+    # 2) Today's date
+    # 3) Today's date
 
-        my $today = to_date($year, $month, $day);
+    my $today = to_date( $year, $month, $day );
 
-        my $return = "";
-        foreach my $sth ($sth_events, $sth_participants) {
-            $sth->execute($object, $today, $today);
-            while (my ($eid, $name, $start_date, $start_time, $end_date, $end_time) = $sth->fetchrow_array) {
-                my ($syear, $smonth, $sday, $shour, $smin, $ssec) = (from_date($start_date), from_time($start_time));
-                my ($eyear, $emonth, $eday, $ehour, $emin, $esec) = (from_date($end_date), from_time($end_time));
-                my $range;
-                if ( $syear == $year and $smonth == $month and $sday == $day ) {
-                    # The event starts today, we need a range
-                    if (defined $start_time) {
-                        if (Compare_YMD($syear, $smonth, $sday, $eyear, $emonth, $eday) == 0 ) {
-                            $range = sprintf '%d:%02d - %d:%02d ', $shour, $smin, $ehour, $emin;
-                        } else {
-                            $range = sprintf '%s %d:%02d - %s %d:%02d ', Date_to_Text_Long( $syear, $smonth, $sday ), $shour, $smin, Date_to_Text_Long( $eyear, $emonth, $eday ), $ehour, $emin;
-                        }
-                    } elsif (Compare_YMD($syear, $smonth, $sday, $eyear, $emonth, $eday) != 0 ) {
-                        $range = Date_to_Text_Long($syear, $smonth, $sday) . " - " . Date_to_Text_Long($eyear, $emonth, $eday) . " ";
+    my $return = "";
+    foreach my $sth ( $sth_events, $sth_participants ) {
+        $sth->execute( $object, $today, $today );
+        while (
+            my ( $eid, $name, $start_date, $start_time, $end_date, $end_time ) =
+            $sth->fetchrow_array )
+        {
+            my ( $syear, $smonth, $sday, $shour, $smin, $ssec ) =
+              ( from_date($start_date), from_time($start_time) );
+            my ( $eyear, $emonth, $eday, $ehour, $emin, $esec ) =
+              ( from_date($end_date), from_time($end_time) );
+            my $range;
+            if ( $syear == $year and $smonth == $month and $sday == $day ) {
+                # The event starts today, we need a range
+                my $format;
+                if ( defined $start_time ) {
+                    if (
+                        Compare_YMD( $syear, $smonth, $sday, $eyear, $emonth,
+                            $eday ) == 0
+                      )
+                    {
+                        $format = $conf->{"${view}_DATE_FORMAT"} || '%k:%M';
+                    } else {
+                        $format = $conf->{"${view}_MULTIDAY_DATE_FORMAT"}
+                          || '%F %k:%M';
                     }
+                } elsif (
+                    Compare_YMD( $syear, $smonth, $sday, $eyear, $emonth,
+                        $eday ) != 0
+                  )
+                {
+                    $format = $conf->{"${view}_MULTIDAY_NOTIME_DATE_FORMAT"}
+                      || '%F';
                 } else {
-                    # The events started another day and continues today. Print
-                    # no range.
+                    $format = $conf->{"${view}_NOTIME_DATE_FORMAT"} || '';
                 }
-
-                $return .= <<EOF;
-            <br>$range<a class=event href="/Chronos?action=editevent&amp;eid=$eid&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">$name</a>
-EOF
+                $range = encode_entities(
+                    sprintf '%s - %s',
+                    $self->format_date(
+                        $format, $syear, $smonth, $sday, 0, 0, 0
+                    ),
+                    $self->format_date(
+                        $format, $eyear, $emonth, $eday, 0, 0, 0
+                    )
+                );
+            } else {
+                # The events started another day and continues today. Print
+                # no range.
             }
-            $sth->finish;
+
+            $return .= <<EOF;
+            <br>&bull; $range <a class=event href="$uri?action=editevent&amp;eid=$eid&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">$name</a>
+EOF
         }
-        return $return;
+        $sth->finish;
     }
+    return $return;
+}
+
+sub format_date {
+    my $self   = shift;
+    my $format = shift;
+    my ( @calc_time, @localtime );
+    if ( @_ == 9 ) {
+        @localtime = @_;
+        @calc_time = ( $_[5] + 1900, $_[4] + 1, @_[ 3 .. 0 ] );
+    } elsif ( @_ == 6 ) {
+        @calc_time = @_;
+        @localtime = localtime( Mktime(@_) );
+    } else {
+        die
+'Usage: format_date(@localtime) or format_date($year, $month, $day, $hour, $min, $sec)';
+    }
+
+    my $long  = Date_to_Text_Long( @calc_time[ 0 .. 2 ] );
+    my $short = Date_to_Text( @calc_time[ 0 .. 2 ] );
+    $format =~ s/\%\(long\)/$long/;
+    $format =~ s/\%\(short\)/$short/;
+    return strftime( $format, @localtime );
 }
 
 1;
