@@ -1,4 +1,4 @@
-# $Id: EditEvent.pm,v 1.21 2002/08/01 01:54:42 nomis80 Exp $
+# $Id: EditEvent.pm,v 1.26 2002/08/12 18:27:35 nomis80 Exp $
 #
 # Copyright (C) 2002  Linux Qubec Technologies
 #
@@ -33,38 +33,44 @@ sub type {
 }
 
 sub authorized {
-    my $self = shift;
-    my $chronos = $self->{parent};
-    my $dbh = $chronos->dbh;
-    my $object = $self->object;
+    my $self          = shift;
+    my $chronos       = $self->{parent};
+    my $dbh           = $chronos->dbh;
+    my $object        = $self->object;
     my $object_quoted = $dbh->quote($object);
 
-    if ($self->SUPER::authorized == 0) {
+    if ( $self->SUPER::authorized == 0 ) {
         return 0;
     }
 
-    if (my $eid = $chronos->{r}->param('eid')) {
-        return 1 if $object eq $dbh->selectrow_array("SELECT initiator FROM events WHERE eid = $eid");
-        return 1 if $dbh->selectrow_array("SELECT user FROM participants WHERE eid = $eid AND user = $object_quoted");
-        return 0
+    if ( my $eid = $chronos->{r}->param('eid') ) {
+        return 1
+          if $object eq $dbh->selectrow_array(
+            "SELECT initiator FROM events WHERE eid = $eid");
+        return 1
+          if $dbh->selectrow_array(
+"SELECT user FROM participants WHERE eid = $eid AND user = $object_quoted"
+          );
+        return 0;
     } else {
         return 1;
     }
 }
 
 sub header {
-    my $self = shift;
+    my $self   = shift;
     my $object = $self->object;
-    my ($year, $month, $day) = $self->{parent}->day;
+    my ( $year, $month, $day ) = $self->{parent}->day;
     my $text = $self->{parent}->gettext;
+    my $uri  = $self->{parent}{r}->uri;
     return <<EOF;
 <table style="margin-style:none" cellspacing=0 cellpadding=0 width="100%">
     <tr>
         <td class=header>@{[Date_to_Text_Long(Today())]}</td>
         <td class=header align=right>
-            <a href="/Chronos?action=showmonth&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">$text->{month}</a> |
-            <a href="/Chronos?action=showweek&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">$text->{week}</a> |
-            <a href="/Chronos?action=showday&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">$text->{Day}</a>
+            <a href="$uri?action=showmonth&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">$text->{month}</a> |
+            <a href="$uri?action=showweek&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">$text->{week}</a> |
+            <a href="$uri?action=showday&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day">$text->{Day}</a>
         </td>
     </tr>
 </table>
@@ -91,8 +97,9 @@ EOF
 
 sub form {
     my $self    = shift;
-    my $object = $self->object;
+    my $object  = $self->object;
     my $chronos = $self->{parent};
+    my $uri     = $chronos->{r}->uri;
     my $text    = $chronos->gettext;
     my ( $year, $month, $day, $hour ) = @_;
     my $dbh = $chronos->dbh;
@@ -100,47 +107,78 @@ sub form {
     my $eid = $chronos->{r}->param('eid');
     my %event;
     if ($eid) {
-        %event = %{ $dbh->selectrow_hashref("SELECT * FROM events WHERE eid = $eid") };
+        %event =
+          %{ $dbh->selectrow_hashref("SELECT * FROM events WHERE eid = $eid") };
     }
-    @event{qw(syear smonth sday shour smin ssec)} = (from_date( $event{start_date} ), from_time( $event{start_time} ));
-    @event{qw(eyear emonth eday ehour emin esec)} = (from_date( $event{end_date} ), from_time( $event{end_time} ));
+    @event{qw(syear smonth sday shour smin ssec)} =
+      ( from_date( $event{start_date} ), from_time( $event{start_time} ) );
+    @event{qw(eyear emonth eday ehour emin esec)} =
+      ( from_date( $event{end_date} ), from_time( $event{end_time} ) );
     if ( $event{rid} ) {
-        @event{qw(recurrent recur_until)} = $dbh->selectrow_array("SELECT every, last FROM recur WHERE rid = $event{rid}");
-        @event{qw(ryear rmonth rday)}     = from_date( $event{recur_until} );
+        @event{qw(recurrent recur_until)} =
+          $dbh->selectrow_array(
+            "SELECT every, last FROM recur WHERE rid = $event{rid}");
+        @event{qw(ryear rmonth rday)} = from_date( $event{recur_until} );
     }
-    my $notime = ($eid and not defined $event{start_time}) ? 1 : 0;
+    my $notime = ( $eid and not defined $event{start_time} ) ? 1 : 0;
 
     if ( $eid and $event{initiator} ne $self->object ) {
         # Modification d'un vnement existant par un participant
-        my $stext = encode_entities( Date_to_Text_Long( @event{qw(syear smonth sday)} ) . ($notime ? '' : sprintf(' %d:%02d', @event{qw(shour smin)})) );
-        my $etext = encode_entities( Date_to_Text_Long( @event{qw(eyear emonth eday)} ) . ($notime ? '' : sprintf(' %d:%02d', @event{qw(ehour emin)})) );
-        my $recur = $event{recurrent} ? $text->{ "eventrecur" . lc $event{recurrent} } : $text->{eventnotrecur};
-        my $rtext = $event{recur_until} ? encode_entities( Date_to_Text_Long( @event{qw(ryear rmonth rday)} ) ) : '-';
+        my $stext =
+          encode_entities( Date_to_Text_Long( @event{qw(syear smonth sday)} )
+              . ( $notime ? '' : sprintf( ' %d:%02d', @event{qw(shour smin)} ) )
+          );
+        my $etext =
+          encode_entities( Date_to_Text_Long( @event{qw(eyear emonth eday)} )
+              . ( $notime ? '' : sprintf( ' %d:%02d', @event{qw(ehour emin)} ) )
+          );
+        my $recur =
+          $event{recurrent}
+          ? $text->{ "eventrecur" . lc $event{recurrent} }
+          : $text->{eventnotrecur};
+        my $rtext =
+          $event{recur_until}
+          ? encode_entities(
+            Date_to_Text_Long( @event{qw(ryear rmonth rday)} ) )
+          : '-';
 
         my $initiator_quoted = $dbh->quote( $event{initiator} );
-        my $participants     = userstring( $dbh->selectrow_array("SELECT user, name, email FROM user WHERE user = $initiator_quoted") ) . " <b>($text->{initiator})</b>";
-        my $sth              =
-          $dbh->prepare(
-            "SELECT user.user, user.name, user.email, participants.status FROM user, participants WHERE participants.eid = $eid AND participants.user = user.user ORDER BY user.name, user.user");
+        my $participants     = userstring(
+            $dbh->selectrow_array(
+"SELECT user, name, email FROM user WHERE user = $initiator_quoted"
+            )
+          )
+          . " <b>($text->{initiator})</b>";
+        my $sth = $dbh->prepare( <<EOF );
+SELECT user.user, user.name, user.email, participants.status
+FROM user, participants
+WHERE
+    participants.eid = $eid
+    AND participants.user = user.user
+ORDER BY user.name, user.user
+EOF
         $sth->execute;
 
         while ( my ( $user, $name, $email, $status ) = $sth->fetchrow_array ) {
             my $userstring = userstring( $user, $name, $email );
-            my $statusstring = defined $status ? "<b>(" . $text->{"status_$status"} . ")</b>" : '';
+            my $statusstring =
+              $status ? "<b>(" . $text->{"status_$status"} . ")</b>" : '';
             $participants .= "<br>$userstring $statusstring";
             if ( $user eq $self->object ) {
                 if ( $status ne 'CANCELED' ) {
-                    $participants .= " <input type=submit name=cancel value=\"$text->{cancel}\">";
+                    $participants .=
+" <input type=submit name=cancel value=\"$text->{cancel}\">";
                 }
                 if ( $status ne 'CONFIRMED' ) {
-                    $participants .= " <input type=submit name=confirm value=\"$text->{confirm}\">";
+                    $participants .=
+" <input type=submit name=confirm value=\"$text->{confirm}\">";
                 }
             }
         }
         $sth->finish;
 
         my $return = <<EOF;
-<form method=POST action="/Chronos" enctype="multipart/form-data" name="form1">
+<form method=POST action="$uri" enctype="multipart/form-data" name="form1">
 <input type=hidden name=action value=saveevent>
 <input type=hidden name=object value="$object">
 <input type=hidden name=year value=$year>
@@ -186,16 +224,22 @@ EOF
         if ( $event{initiator} eq $self->object ) {
             $reminder_datetime = $event{reminder};
         } else {
-            $reminder_datetime = $dbh->selectrow_array("SELECT reminder FROM participants WHERE eid = $eid");
+            $reminder_datetime =
+              $dbh->selectrow_array(
+                "SELECT reminder FROM participants WHERE eid = $eid");
         }
         if ( defined $reminder_datetime ) {
-            my ( $Dd, $Dh, $Dm ) = Delta_DHMS( from_datetime($reminder_datetime), from_date( $event{start_date} ), from_time( $event{start_time} ) );
-            if ($Dd and not $Dh) {
+            my ( $Dd, $Dh, $Dm ) = Delta_DHMS(
+                from_datetime($reminder_datetime),
+                from_date( $event{start_date} ),
+                from_time( $event{start_time} )
+            );
+            if ( $Dd and not $Dh ) {
                 $selunit{day} = 'selected';
                 $selnumber{$Dd} = 'selected';
             } elsif ($Dh) {
                 $selunit{hour} = 'selected';
-                $selnumber{$Dh + 24 * $Dd} = 'selected';
+                $selnumber{ $Dh + 24 * $Dd } = 'selected';
             } elsif ($Dm) {
                 $selunit{min} = 'selected';
                 $selnumber{$Dm} = 'selected';
@@ -209,7 +253,8 @@ EOF
         $reminder_number .= "</select>";
         my $reminder_unit = "<select name=reminder_unit>";
         foreach (qw(min hour day)) {
-            $reminder_unit .= "<option value=$_ $selunit{$_}>$text->{$_}</option>";
+            $reminder_unit .=
+              "<option value=$_ $selunit{$_}>$text->{$_}</option>";
         }
         $reminder_unit .= "</select>";
         my $remind_me = $text->{remind_me};
@@ -224,23 +269,32 @@ EOF
         <td class=eventlabel>$text->{attachments}</td>
         <td>
 EOF
-        if ($dbh->selectrow_array("SELECT COUNT(*) FROM attachments WHERE eid = $eid")) {
+        if (
+            $dbh->selectrow_array(
+                "SELECT COUNT(*) FROM attachments WHERE eid = $eid"
+            )
+          )
+        {
             $return .= <<EOF;
             <table class=attachments>
 EOF
-            my $sth_files = $dbh->prepare("SELECT aid, filename, size FROM attachments WHERE eid = $eid ORDER BY filename");
+            my $sth_files =
+              $dbh->prepare(
+"SELECT aid, filename, size FROM attachments WHERE eid = $eid ORDER BY filename"
+              );
             $sth_files->execute;
-            while (my ($aid, $filename, $size) = $sth_files->fetchrow_array) {
+            while ( my ( $aid, $filename, $size ) = $sth_files->fetchrow_array )
+            {
                 $filename = encode_entities($filename);
-                $size = format_size($size);
+                $size     = format_size($size);
                 $return .= <<EOF;
                 <tr>
                     <td class=attachment>
-                        <a href="/Chronos/getfile/$aid/$filename" class=attachment>$filename</a>
+                        <a href="$uri/getfile/$aid/$filename" class=attachment>$filename</a>
                     </td>
                     <td class=attachment>$size</td>
                     <td valign=top>
-                        <a href="/Chronos?action=delfile&amp;aid=$aid&amp;eid=$eid&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day"><img src="/chronos_static/trash.png"></a>
+                        <a href="$uri?action=delfile&amp;aid=$aid&amp;eid=$eid&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day"><img src="/chronos_static/trash.png"></a>
                     </td>
                 </tr>
 EOF
@@ -250,7 +304,7 @@ EOF
             $return .= <<EOF;
             </table>
 EOF
-            }
+        }
         $return .= <<EOF;
         $text->{new_attachment} <input type=file name=new_attachment>
         </td>
@@ -276,7 +330,7 @@ EOF
     } else {
         # Cration d'un nouvel vnement ou modification d'un vnement existant par l'initiateur
         my $return = <<EOF;
-<form method=POST action="/Chronos" enctype="multipart/form-data" name="form1">
+<form method=POST action="$uri" enctype="multipart/form-data" name="form1">
 <input type=hidden name=action value=saveevent>
 <input type=hidden name=object value="$object">
 <input type=hidden name=year value=$year>
@@ -390,7 +444,8 @@ EOF
             <select name=end_hour style="visibility:@{[$notime ? 'hidden' : 'visible']}">
 EOF
         foreach ( '00' .. '23' ) {
-            my $selected = $_ == ( $event{ehour} || $hour + 2 ) ? 'selected' : '';
+            my $selected =
+              $_ == ( $event{ehour} || $hour + 2 ) ? 'selected' : '';
             my $value = int $_;
             $return .= <<EOF;
                 <option value=$value $selected>$_</option>
@@ -452,7 +507,8 @@ EOF
 EOF
             foreach ( 1 .. 12 ) {
                 my $month_name = Month_to_Text($_);
-                my $selected = $_ == ( $event{rmonth} || $month ) ? 'selected' : '';
+                my $selected   =
+                  $_ == ( $event{rmonth} || $month ) ? 'selected' : '';
                 $return .= <<EOF;
                 <option value=$_ $selected>$month_name</option>
 EOF
@@ -472,7 +528,8 @@ EOF
             <select name=recur_end_year>
 EOF
             foreach ( ( $year - 5 ) .. ( $year + 5 ) ) {
-                my $selected = $_ == ( $event{ryear} || $year ) ? 'selected' : '';
+                my $selected =
+                  $_ == ( $event{ryear} || $year ) ? 'selected' : '';
                 $return .= <<EOF;
                 <option $selected>$_</option>
 EOF
@@ -483,8 +540,15 @@ EOF
     </tr>
 EOF
         } else {
-            my $recur = $event{recurrent} ? $text->{ "eventrecur" . lc $event{recurrent} } : $text->{eventnotrecur};
-            my $rtext = $event{recur_until} ? encode_entities( Date_to_Text_Long( @event{qw(ryear rmonth rday)} ) ) : '-';
+            my $recur =
+              $event{recurrent}
+              ? $text->{ "eventrecur" . lc $event{recurrent} }
+              : $text->{eventnotrecur};
+            my $rtext =
+              $event{recur_until}
+              ? encode_entities(
+                Date_to_Text_Long( @event{qw(ryear rmonth rday)} ) )
+              : '-';
             $return .= <<EOF;
     <tr>
         <td class=eventlabel>$text->{eventrecur}</td>
@@ -496,7 +560,7 @@ EOF
     </tr>
 EOF
         }
-            
+
         $return .= <<EOF;
     <tr>
         <td class=eventlabel>$text->{eventparticipants}</td>
@@ -505,7 +569,9 @@ EOF
 
         if ($eid) {
             my ( $user, $name, $email ) =
-              $dbh->selectrow_array("SELECT user.user, user.name, user.email FROM user, events WHERE events.eid = $eid AND events.initiator = user.user");
+              $dbh->selectrow_array(
+"SELECT user.user, user.name, user.email FROM user, events WHERE events.eid = $eid AND events.initiator = user.user"
+              );
             my $initiator = $self->{parent}->user eq $user ? 1 : 0;
             my $userstring = userstring( $user, $name, $email );
             $return .= <<EOF;
@@ -514,27 +580,34 @@ EOF
 
             my $sth =
               $dbh->prepare(
-                "SELECT user.user, user.name, user.email, participants.status FROM user, participants WHERE participants.eid = $eid AND participants.user = user.user ORDER BY user.name, user.user");
+"SELECT user.user, user.name, user.email, participants.status FROM user, participants WHERE participants.eid = $eid AND participants.user = user.user ORDER BY user.name, user.user"
+              );
             $sth->execute;
             my %participants;
-            while ( my ( $user, $name, $email, $status ) = $sth->fetchrow_array ) {
+            while ( my ( $user, $name, $email, $status ) =
+                $sth->fetchrow_array )
+            {
                 $participants{$user} = 1;
                 my $userstring = userstring( $user, $name, $email );
-                my $statusstring = defined $status ? "<b>(" . $text->{"status_$status"} . ")</b>" : '';
+                my $statusstring =
+                  $status ? "<b>(" . $text->{"status_$status"} . ")</b>" : '';
                 $return .= <<EOF;
             <br>$userstring $statusstring
 EOF
                 if ( $user eq $self->object ) {
                     if ( $status ne 'CANCELED' ) {
-                        $return .= "<input type=submit name=cancel value=\"$text->{cancel}\">";
+                        $return .=
+"<input type=submit name=cancel value=\"$text->{cancel}\">";
                     }
                     if ( $status ne 'CONFIRMED' ) {
-                        $return .= "<input type=submit name=confirm value=\"$text->{confirm}\">";
+                        $return .=
+"<input type=submit name=confirm value=\"$text->{confirm}\">";
                     }
                 }
 
-                if ( $initiator ) {
-                    $return .= "<input type=submit name=\"remove_$user\" value=\"$text->{remove_part}\">";
+                if ($initiator) {
+                    $return .=
+"<input type=submit name=\"remove_$user\" value=\"$text->{remove_part}\">";
                 }
             }
             $sth->finish;
@@ -547,11 +620,15 @@ EOF
             <td>
                 <select size=5 multiple name=participants>
 EOF
-            $sth = $dbh->prepare("SELECT user, name, email FROM user WHERE user != ? AND user != ? ORDER BY name, user");
-            $sth->execute($self->object, $user);
-            while (my ($user, $name, $email) = $sth->fetchrow_array) {
+            $sth =
+              $dbh->prepare(
+"SELECT user, name, email FROM user WHERE user != ? AND user != ? ORDER BY name, user"
+              );
+            $sth->execute( $self->object, $user );
+            while ( my ( $user, $name, $email ) = $sth->fetchrow_array ) {
                 next if $participants{$user};
-                my $string = ($name || $user) . ($email ? " &lt;$email&gt;" : '');
+                my $string =
+                  ( $name || $user ) . ( $email ? " &lt;$email&gt;" : '' );
                 $return .= <<EOF;
                     <option value="$user">$string</option>
 EOF
@@ -567,10 +644,14 @@ EOF
             $return .= <<EOF;
             <select size=5 multiple name=participants>
 EOF
-            my $sth = $dbh->prepare("SELECT user, name, email FROM user WHERE user != ? ORDER BY name, user");
+            my $sth =
+              $dbh->prepare(
+"SELECT user, name, email FROM user WHERE user != ? ORDER BY name, user"
+              );
             $sth->execute( $self->object );
             while ( my ( $user, $name, $email ) = $sth->fetchrow_array ) {
-                my $string = ($name || $user) . ($email ? " &lt;$email&gt;" : '');
+                my $string =
+                  ( $name || $user ) . ( $email ? " &lt;$email&gt;" : '' );
                 $return .= <<EOF;
                 <option value="$user">$string</option>
 EOF
@@ -604,18 +685,22 @@ EOF
             if ( $event{initiator} eq $self->object ) {
                 $reminder_datetime = $event{reminder};
             } else {
-                $reminder_datetime = $dbh->selectrow_array("SELECT reminder FROM participants WHERE eid = $eid");
+                $reminder_datetime =
+                  $dbh->selectrow_array(
+                    "SELECT reminder FROM participants WHERE eid = $eid");
             }
             if ( defined $reminder_datetime ) {
-                my @start_time = from_time($event{start_time});
-                @start_time = (0, 0, 0) if not @start_time;
-                my ( $Dd, $Dh, $Dm ) = Delta_DHMS( from_datetime($reminder_datetime), from_date( $event{start_date} ), @start_time );
-                if ($Dd and not $Dh) {
+                my @start_time = from_time( $event{start_time} );
+                @start_time = ( 0, 0, 0 ) if not @start_time;
+                my ( $Dd, $Dh, $Dm ) =
+                  Delta_DHMS( from_datetime($reminder_datetime),
+                    from_date( $event{start_date} ), @start_time );
+                if ( $Dd and not $Dh ) {
                     $selunit{day} = 'selected';
                     $selnumber{$Dd} = 'selected';
                 } elsif ($Dh) {
                     $selunit{hour} = 'selected';
-                    $selnumber{$Dh + 24 * $Dd} = 'selected';
+                    $selnumber{ $Dh + 24 * $Dd } = 'selected';
                 } elsif ($Dm) {
                     $selunit{min} = 'selected';
                     $selnumber{$Dm} = 'selected';
@@ -630,7 +715,8 @@ EOF
         $reminder_number .= "</select>";
         my $reminder_unit = "<select name=reminder_unit>";
         foreach (qw(min hour day)) {
-            $reminder_unit .= "<option value=$_ $selunit{$_}>$text->{$_}</option>";
+            $reminder_unit .=
+              "<option value=$_ $selunit{$_}>$text->{$_}</option>";
         }
         $reminder_unit .= "</select>";
         my $remind_me = $text->{remind_me};
@@ -645,23 +731,33 @@ EOF
         <td class=eventlabel>$text->{attachments}</td>
         <td>
 EOF
-        if ($eid and $dbh->selectrow_array("SELECT COUNT(*) FROM attachments WHERE eid = $eid")) {
+        if (
+            $eid
+            and $dbh->selectrow_array(
+                "SELECT COUNT(*) FROM attachments WHERE eid = $eid"
+            )
+          )
+        {
             $return .= <<EOF;
             <table class=attachments>
 EOF
-            my $sth_files = $dbh->prepare("SELECT aid, filename, size FROM attachments WHERE eid = $eid ORDER BY filename");
+            my $sth_files =
+              $dbh->prepare(
+"SELECT aid, filename, size FROM attachments WHERE eid = $eid ORDER BY filename"
+              );
             $sth_files->execute;
-            while (my ($aid, $filename, $size) = $sth_files->fetchrow_array) {
+            while ( my ( $aid, $filename, $size ) = $sth_files->fetchrow_array )
+            {
                 $filename = encode_entities($filename);
-                $size = format_size($size);
+                $size     = format_size($size);
                 $return .= <<EOF;
                 <tr>
                     <td class=attachment>
-                        <a href="/Chronos/getfile/$aid/$filename" class=attachment>$filename</a>
+                        <a href="$uri/getfile/$aid/$filename" class=attachment>$filename</a>
                     </td>
                     <td class=attachment>$size</td>
                     <td valign=top>
-                        <a href="/Chronos?action=delfile&amp;aid=$aid&amp;eid=$eid&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day"><img src="/chronos_static/trash.png"></a>
+                        <a href="$uri?action=delfile&amp;aid=$aid&amp;eid=$eid&amp;object=$object&amp;year=$year&amp;month=$month&amp;day=$day"><img src="/chronos_static/trash.png"></a>
                     </td>
                 </tr>
 EOF
@@ -702,11 +798,11 @@ EOF
 
 sub format_size {
     my $size = shift;
-    if ($size >= 1024 * 1024 * 1024 ) {
+    if ( $size >= 1024 * 1024 * 1024 ) {
         return sprintf '%0.1f GB', $size / ( 1024 * 1024 * 1024 );
-    } elsif ($size >= 1024 * 1024 ) {
+    } elsif ( $size >= 1024 * 1024 ) {
         return sprintf '%0.1f MB', $size / ( 1024 * 1024 );
-    } elsif ($size >= 1024 ) {
+    } elsif ( $size >= 1024 ) {
         return sprintf '%0.1f kB', $size / 1024;
     } else {
         return "$size B";
